==> estateplat-common-1.2.4-20201230.022635-603-sources.jar: cn/gtmap/estateplat/model/server/core/DjsjFwzbxx.java <==
package cn.gtmap.estateplat.model.server.core;

import java.util.Date;

/**
 * Created by zhangxing on 2015/4/17.
 * 房屋子表信息
 */
public class DjsjFwzbxx {
    private String xmmc;
    private String dh;
    private int zcs;
    private String ghyt;
    private String fwjg;
    private Double jzmj;
    private Date jgsj;
    private String zts;
    private Double dycs;
    private Double zzdmj;
    private Integer jznd;//建筑年代


    /**
     * @author <a href="mailto:liujie@gtmap.cn">liujie</a>
     * @description 不动产单元编号
     */
    private String bdcdybh;


    public Double getDycs() {
        return dycs;
    }

    public void setDycs(Double dycs) {
        this.dycs = dycs;
    }

    public String getXmmc() {

        return xmmc;
    }

    public void setXmmc(String xmmc) {
        this.xmmc = xmmc;
    }

    public String getDh() {
        return dh;
    }

    public void setDh(String dh) {
        this.dh = dh;
    }

    public int getZcs() {
        return zcs;
    }

    public void setZcs(int zcs) {
        this.zcs = zcs;
    }

    public String getGhyt() {
        return ghyt;
    }

    public void setGhyt(String ghyt) {
        this.ghyt = ghyt;
    }

    public String getFwjg() {
        return fwjg;
    }

    public void setFwjg(String fwjg) {
        this.fwjg = fwjg;
    }

    public Double getJzmj() {
        return jzmj;
    }

    public void setJzmj(Double jzmj) {
        this.jzmj = jzmj;
    }

    public Date getJgsj() {
        return jgsj;
    }

    public void setJgsj(Date jgsj) {
        this.jgsj = jgsj;
    }

    public String getZts() {
        return zts;
    }

    public void setZts(String zts) {
        this.zts = zts;
    }

    public Double getZzdmj() {
        return zzdmj;
    }

    public void setZzdmj(Double zzdmj) {
        this.zzdmj = zzdmj;
    }

    public Integer getJznd() {
        return jznd;
    }

    public void setJznd(Integer jznd) {
        this.jznd = jznd;
    }

    public String getBdcdybh() {
        return bdcdybh;
    }

    public void setBdcdybh(String bdcdybh) {
        this.bdcdybh = bdcdybh;
    }
}

==> estateplat-common-1.2.4-20220630.085944-1060-sources.jar: cn/gtmap/estateplat/model/server/core/DjsjFwzbxx.java <==
package cn.gtmap.estateplat.model.server.core;

import java.util.Date;

/**
 * Created by zhangxing on 2015/4/17.
 * 房屋子表信息
 */
public class DjsjFwzbxx {
    private String xmmc;
    private String dh;
    private int zcs;
    private String ghyt;
    private String fwjg;
    private Double jzmj;
    private Date jgsj;
    private String zts;
    private Double dycs;
    private Double zzdmj;
    private Integer jznd;//建筑年代
    private String ytmc;//用途名称
    private String pzyt;//批准用途
    private String sjyt;//实际用途


    /**
     * @author <a href="mailto:liujie@gtmap.cn">liujie</a>
     * @description 不动产单元编号
     */
    private String bdcdybh;


    public Double getDycs() {
        return dycs;
    }

    public void setDycs(Double dycs) {
        this.dycs = dycs;
    }

    public String getXmmc() {

        return xmmc;
    }

    public void setXmmc(String xmmc) {
        this.xmmc = xmmc;
    }

    public String getDh() {
        return dh;
    }

    public void setDh(String dh) {
        this.dh = dh;
    }

    public int getZcs() {
        return zcs;
    }

    public void setZcs(int zcs) {
        this.zcs = zcs;
    }

    public String getGhyt() {
        return ghyt;
    }

    public void setGhyt(String ghyt) {
        this.ghyt = ghyt;
    }

    public String getFwjg() {
        return fwjg;
    }

    public void setFwjg(String fwjg) {
        this.fwjg = fwjg;
    }

    public Double getJzmj() {
        return jzmj;
    }

    public void setJzmj(Double jzmj) {
        this.jzmj = jzmj;
    }

    public Date getJgsj() {
        return jgsj;
    }

    public void setJgsj(Date jgsj) {
        this.jgsj = jgsj;
    }

    public String getZts() {
        return zts;
    }

    public void setZts(String zts) {
        this.zts = zts;
    }

    public Double getZzdmj() {
        return zzdmj;
    }

    public void setZzdmj(Double zzdmj) {
        this.zzdmj = zzdmj;
    }

    public Integer getJznd() {
        return jznd;
    }

    public void setJznd(Integer jznd) {
        this.jznd = jznd;
    }

    public String getBdcdybh() {
        return bdcdybh;
    }

    public void setBdcdybh(String bdcdybh) {
        this.bdcdybh = bdcdybh;
    }

    public String getYtmc() {
        return ytmc;
    }

    public void setYtmc(String ytmc) {
        this.ytmc = ytmc;
    }

    public String getPzyt() {
        return pzyt;
    }

    public void setPzyt(String pzyt) {
        this.pzyt = pzyt;
    }

    public String getSjyt() {
        return sjyt;
    }

    public void setSjyt(String sjyt) {
        this.sjyt = sjyt;
    }
}
